# dansinke.mk:danse共通インクルードファイル Version 7.41e  Copyleft (c) 杉本典夫
# Time-stamp: <2024-04-28 08:25:53 tac>
#
# 使用法:各Makefileにインクルードして使用する
# 各Makefileでは$(name)と$(coms)を設定する。
# $(LINCDIR),$(LLIBDIR),$(LBINDIR),$(LMANDIR)はdirinke.mk中で設定し、
# それをこのファイルより先に各Makefileにインクルードして使用する
#        make         … 実行ファイルと圧縮アーカイブファイルを作成する
#        make arcs    … 圧縮アーカイブファイルを作成する
#        make install … 実行ファイルとドキュメントファイルをインストールする
#        make debs    … デバッグ用実行ファイルを作成する
#        make clean   … 不要なファイルを削除する

outs = $(addsuffix .out,$(coms))
debs = $(outs:.out=.db)
sous = $(outs:.out=.C)
mans = $(outs:.out=.1)
bshs = $(outs:.out=.bsh)
txts = $(outs:.out=_*_v*.txt)
dats = $(outs:.out=_*_v*.dat)
tabs = $(outs:.out=_*_v*.tab)
dnss = $(outs:.out=_*_v*.d)

arcs = $(name).zip
addfiles = Makefile

HEADS := $(LINCDIR)/fune.H $(LINCDIR)/mate.H $(LINCDIR)/danse.H

CXX := g++
CXXFLAGS := -O -s -W -I$(LINCDIR)
DEBFLAGS := -g -W -I$(LINCDIR)
LDFLAGS := -L$(LLIBDIR) -ldanse -lfune

ARCOM := zip
ARCOMFLAGS := -u

all : $(outs) $(arcs)

arcs : $(arcs)

debs : $(debs)

$(outs) : $(HEADS)
# パターンルールを使用する

$(debs) : $(HEADS)
# パターンルールを使用する

$(arcs) : $(sous) $(mans) $(bshs) $(addfiles)
	$(ARCOM) $(ARCOMFLAGS) $@ $?

%.out : %.C
	$(CXX) $(CXXFLAGS) -o $@ $< $(LDFLAGS)

%.db : %.C
	$(CXX) $(DEBFLAGS) -o $@ $< $(LDFLAGS)

install : installout installman

installout : $(outs)
	for file in $? ; do cp -f -p $$file $(LBINDIR)/$${file%.out} ; done

installman : $(mans)
	for file in $? ; do cp -f -p $(PWD)/$$file $(LMANDIR) ; done

clean :
	rm -f $(debs) $(txts) $(dats) $(tabs) $(dnss)
